@@ -160,6 +160,8 @@ class MemoryReader:
             if module_object is None:
                 raise ValueError(f"{module} module not found.")
 
+            # this can take a long time to run when collecting multiple results
+            # so must be run in an executor
             found_addresses = await self.run_in_executor(
                 self._scan_entire_module,
                 self.process.process_handle,
@@ -175,9 +177,6 @@ class MemoryReader:
                 return_multiple,
             )
 
-        logger.debug(
-            f"Got results (first 10) {found_addresses[:10]} from pattern {pattern}"
-        )
         if (found_length := len(found_addresses)) == 0:
             raise PatternFailed(pattern)
         elif found_length > 1 and not return_multiple:
@@ -241,7 +240,7 @@ class MemoryReader:
         Returns:
             The allocated address
         """
-        return await self.run_in_executor(self.process.allocate, size)
+        return self.process.allocate(size)
 
     async def free(self, address: int):
         """
@@ -250,7 +249,7 @@ class MemoryReader:
         Args:
              address: The address to free
         """
-        await self.run_in_executor(self.process.free, address)
+        self.process.free(address)
 
     # TODO: figure out how params works
     async def start_thread(self, address: int):
@@ -279,7 +278,7 @@ class MemoryReader:
             raise AddressOutOfRange(address)
 
         try:
-            return await self.run_in_executor(self.process.read_bytes, address, size)
+            return self.process.read_bytes(address, size)
         except pymem.exception.MemoryReadError:
             # we don't want to run is running for every read
             # so we just check after we error
@@ -297,14 +296,9 @@ class MemoryReader:
             value: The bytes to write
         """
         size = len(value)
-        logger.debug(f"Writing bytes {value} to address {address} with size {size}")
+
         try:
-            await self.run_in_executor(
-                self.process.write_bytes,
-                address,
-                value,
-                size,
-            )
+            self.process.write_bytes(address, value, size)
         except pymem.exception.MemoryWriteError:
             # see read_bytes
             if not self.is_running():
